emacs-bug-tracker
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[debbugs-tracker] bug#10421: closed (Don't use the abbreviation "win" to


From: GNU bug Tracking System
Subject: [debbugs-tracker] bug#10421: closed (Don't use the abbreviation "win" to refer to Windows.)
Date: Sun, 29 Jul 2012 08:28:02 +0000

Your message dated Sun, 29 Jul 2012 01:20:48 -0700
with message-id <address@hidden>
and subject line Re: bug#10421: Don't use the abbreviation "win" to refer to 
Windows.
has caused the debbugs.gnu.org bug report #10421,
regarding Don't use the abbreviation "win" to refer to Windows.
to be marked as done.

(If you believe you have received this mail in error, please contact
address@hidden)


-- 
10421: http://debbugs.gnu.org/cgi/bugreport.cgi?bug=10421
GNU Bug Tracking System
Contact address@hidden with problems
--- Begin Message --- Subject: Don't use the abbreviation "win" to refer to Windows. Date: Sun, 01 Jan 2012 22:45:52 -0800 User-agent: Mozilla/5.0 (X11; Linux i686; rv:8.0) Gecko/20111124 Thunderbird/8.0
I found several instances in the Emacs source code of its
unnecessarily using the abbreviation "win" to refer to Windows.
Here's a proposed patch.

=== modified file 'doc/misc/ChangeLog'
--- doc/misc/ChangeLog  2011-12-28 06:59:21 +0000
+++ doc/misc/ChangeLog  2012-01-02 06:41:42 +0000
@@ -4065,7 +4065,7 @@
 2007-11-07  Michael Albinus  <address@hidden>
 
        * tramp.texi (Overview): Mention also the PuTTY integration under
-       Win32.  Remove paragraphs about Tramp's experimental status.
+       w32.  Remove paragraphs about Tramp's experimental status.
        (Frequently Asked Questions): Add code example for highlighting the
        mode line.
 

=== modified file 'doc/misc/gnus-faq.texi'
--- doc/misc/gnus-faq.texi      2011-12-12 05:32:49 +0000
+++ doc/misc/gnus-faq.texi      2012-01-02 06:41:42 +0000
@@ -407,7 +407,7 @@
 The first thing you've got to do is to
 create a suitable directory (no blanks in directory name
 please) e.g. c:\myhome. Then you must set the environment
-variable HOME to this directory.  To do this under Win9x
+variable HOME to this directory.  To do this under Windows 9x
 or Me include the line
 
 @example

=== modified file 'doc/misc/gnus.texi'
--- doc/misc/gnus.texi  2011-12-31 01:27:15 +0000
+++ doc/misc/gnus.texi  2012-01-02 06:41:42 +0000
@@ -30020,7 +30020,7 @@
 
 @lisp
 (("summary"
-  ("win95" -10000 nil s)
+  ("Windows 95" -10000 nil s)
   ("Gnus"))
  ("from"
   ("Lars" -1000))

=== modified file 'doc/misc/idlwave.texi'
--- doc/misc/idlwave.texi       2011-12-19 06:21:24 +0000
+++ doc/misc/idlwave.texi       2012-01-02 06:41:42 +0000
@@ -4020,7 +4020,7 @@
 @end example
 
 @html
-<A NAME="WIN_MAC"></A>
+<A NAME="WINDOWS_MAC"></A>
 @end html
 @node Windows and MacOS, Troubleshooting, Configuration Examples, Top
 @appendix Windows and MacOS

=== modified file 'doc/misc/mh-e.texi'
--- doc/misc/mh-e.texi  2011-09-21 05:22:17 +0000
+++ doc/misc/mh-e.texi  2012-01-02 06:41:42 +0000
@@ -7901,7 +7901,7 @@
 MAILDIR=$HOME/`mhparam Path`
 
 #
-# Filter messages with win32 executables/virii.
+# Filter messages with w32 executables/virii.
 #
 # These attachments are base64 and have a TVqQAAMAAAAEAAAA//8AALg
 # pattern. The string "this program cannot be run in MS-DOS mode"
@@ -9060,5 +9060,3 @@
 @c Local Variables:
 @c sentence-end-double-space: nil
 @c End:
-
-

=== modified file 'lisp/ChangeLog'
--- lisp/ChangeLog      2012-01-01 16:26:51 +0000
+++ lisp/ChangeLog      2012-01-02 06:41:42 +0000
@@ -3292,7 +3292,7 @@
        (tramp-completion-file-name-regexp-unified)
        (tramp-completion-file-name-regexp-separate)
        (tramp-completion-file-name-regexp-url): Don't use leading volume
-       letter on win32 systems.  (Bug#5303, Bug#9311)
+       letter on w32 systems.  (Bug#5303, Bug#9311)
        (tramp-drop-volume-letter): Simplify definition.
        Suggested by Stefan Monnier <address@hidden>.
 

=== modified file 'lisp/ChangeLog.8'
--- lisp/ChangeLog.8    2011-11-27 04:43:11 +0000
+++ lisp/ChangeLog.8    2012-01-02 06:41:42 +0000
@@ -6906,7 +6906,7 @@
        standard `print' and `nprint' programs, as well as `lpr' and
        similar programs.  Only write directly to the printer port if no
        print program is specified.  Work around a bug in Windows 9x
-       affecting Win32 version of Emacs by invoking command.com to write
+       affecting the w32 version of Emacs by invoking command.com to write
        to the printer port instead of writing directly.
        (direct-print-region-function): Use direct-print-region-helper to
        do most of the work.

=== modified file 'lisp/dos-w32.el'
--- lisp/dos-w32.el     2011-05-23 17:57:17 +0000
+++ lisp/dos-w32.el     2012-01-02 06:41:42 +0000
@@ -356,7 +356,7 @@
          (apply 'call-process lpr-prog nil errbuf nil rest))
         ;; Run command.com to access printer port on Windows 9x, unless
         ;; we are supposed to append to an existing (non-empty) file,
-        ;; to work around a bug in Windows 9x that prevents Win32
+        ;; to work around a bug in Windows 9x that prevents w32
         ;; programs from accessing LPT ports reliably.
         ((and (eq system-type 'windows-nt)
               (getenv "winbootdir")

=== modified file 'lisp/mail/feedmail.el'
--- lisp/mail/feedmail.el       2011-11-23 07:03:56 +0000
+++ lisp/mail/feedmail.el       2012-01-02 06:41:42 +0000
@@ -2343,7 +2343,7 @@
     (if (and is-fqm is-in-this-dir)
        (setq filename buffer-file-name)
       (setq filename (feedmail-create-queue-filename queue-directory)))
-    ;; make binary file on DOS/Win95/WinNT, etc
+    ;; make binary file on DOS/Windows 95/Windows NT, etc
     (let ((buffer-file-type feedmail-force-binary-write))
       (write-file filename))
     ;; convenient for moving from draft to q, for example

=== modified file 'lisp/mh-e/ChangeLog.1'
--- lisp/mh-e/ChangeLog.1       2011-12-19 15:46:50 +0000
+++ lisp/mh-e/ChangeLog.1       2012-01-02 06:41:42 +0000
@@ -9493,9 +9493,9 @@
        * mh-utils.el (mh-find-progs): Run PATH search only when mh-progs,
        mh-lib and mh-lib-progs are not all already set.  This allows the
        user to set them using a simple setq prior to loading mh-e.  This
-       is useful for implementation of mh-e on win32.  Note that many
+       is useful for implementation of mh-e on w32.  Note that many
        commands still call mh-find-path which also parses the mh_profile
-       file (that may still fail on win32), so this is still done often.
+       file (that may still fail on w32), so this is still done often.
        But it lets us change the mh_profile file and have mh-e see the
        changed file without exiting emacs and starting over so I left
        that in.

=== modified file 'lisp/net/ange-ftp.el'
--- lisp/net/ange-ftp.el        2011-12-23 14:31:35 +0000
+++ lisp/net/ange-ftp.el        2012-01-02 06:41:42 +0000
@@ -2597,7 +2597,7 @@
                                          (format
                                           "list data file %s not readable"
                                           temp))))
-                      ;; remove ^M inserted by the win32 ftp client
+                      ;; remove ^M inserted by the w32 ftp client
                       (while (re-search-forward "\r$" nil t)
                         (replace-match ""))
                       (goto-char 1)

=== modified file 'lisp/org/ChangeLog'
--- lisp/org/ChangeLog  2011-12-30 02:52:49 +0000
+++ lisp/org/ChangeLog  2012-01-02 06:41:42 +0000
@@ -1,3 +1,12 @@
+2012-01-02  Paul Eggert  <address@hidden>
+
+       Don't use the abbreviation "win" to refer to Windows.
+       * ob-lilypond.el (ly-w32-ly-path): Rename from ly-win32-ly-path.
+       (ly-w32-pdf-path): Rename from ly-win32-pdf-path.
+       (ly-w32-midi-path): Rename from ly-win32-midi-path.
+       (ly-determine-ly-path, ly-determine-pdf-path, ly-determine-midi-path):
+       Check for "windows-nt", not "win32", in system-type.
+
 2011-12-06  Juanma Barranquero  <address@hidden>
 
        * ob.el (org-babel-expand-body:generic, org-babel-number-p):

=== modified file 'lisp/org/ob-lilypond.el'
--- lisp/org/ob-lilypond.el     2011-08-16 07:13:02 +0000
+++ lisp/org/ob-lilypond.el     2012-01-02 06:41:42 +0000
@@ -71,9 +71,9 @@
 (defvar ly-nix-pdf-path "evince")
 (defvar ly-nix-midi-path "timidity")
 
-(defvar ly-win32-ly-path "lilypond")
-(defvar ly-win32-pdf-path "")
-(defvar ly-win32-midi-path "")
+(defvar ly-w32-ly-path "lilypond")
+(defvar ly-w32-pdf-path "")
+(defvar ly-w32-midi-path "")
 
 (defvar ly-gen-png nil
 "Image generation (png) can be turned on by default by setting
@@ -115,7 +115,7 @@
                body))))
      vars)
     body))
- 
+
 (defun org-babel-execute:lilypond (body params)
   "This function is called by `org-babel-execute-src-block'.
 Depending on whether we are in arrange mode either:
@@ -139,7 +139,7 @@
 
 (defun ly-process-basic (body params)
   "Execute a lilypond block in basic mode"
-  
+
   (let* ((result-params (cdr (assoc :result-params params)))
         (out-file (cdr (assoc :file params)))
         (cmdline (or (cdr (assoc :cmdline params))
@@ -148,7 +148,7 @@
 
     (with-temp-file in-file
       (insert (org-babel-expand-body:generic body params)))
-    
+
     (org-babel-eval
      (concat
       (ly-determine-ly-path)
@@ -178,7 +178,7 @@
           (ly-temp-file (ly-switch-extension
                          (buffer-file-name) ".ly")))
       (if (file-exists-p ly-tangled-file)
-          (progn 
+          (progn
             (when (file-exists-p ly-temp-file)
               (delete-file ly-temp-file))
             (rename-file ly-tangled-file
@@ -244,7 +244,7 @@
   "Mark the erroneous lines in the lilypond org buffer.
 FILE-NAME is full path to lilypond file.
 LINE is the erroneous line"
- 
+
   (switch-to-buffer-other-window
    (concat (file-name-nondirectory
             (ly-switch-extension file-name ".org"))))
@@ -257,7 +257,7 @@
           (set-mark (point))
           (goto-char (- (point) (length line))))
       (goto-char temp))))
-  
+
 (defun ly-parse-line-num (&optional buffer)
   "Extract error line number."
 
@@ -285,7 +285,7 @@
   "Extract the erroneous line from the tangled .ly file
 FILE-NAME is full path to lilypond file.
 LINENO is the number of the erroneous line"
- 
+
   (with-temp-buffer
     (insert-file-contents (ly-switch-extension file-name ".ly")
                          nil nil nil t)
@@ -295,12 +295,12 @@
          (forward-line (- lineNo 1))
          (buffer-substring (point) (point-at-eol)))
       nil)))
-    
+
 (defun ly-attempt-to-open-pdf (file-name &optional test)
   "Attempt to display the generated pdf file
 FILE-NAME is full path to lilypond file
 If TEST is non-nil, the shell command is returned and is not run"
-  
+
   (when ly-display-pdf-post-tangle
     (let ((pdf-file (ly-switch-extension file-name ".pdf")))
       (if (file-exists-p pdf-file)
@@ -334,37 +334,37 @@
          (or test system-type)))
     (cond ((string= sys-type  "darwin")
            ly-OSX-ly-path)
-          ((string= sys-type "win32")
-           ly-win32-ly-path)
+          ((string= sys-type "windows-nt")
+           ly-w32-ly-path)
           (t ly-nix-ly-path))))
 
 (defun ly-determine-pdf-path (&optional test)
   "Return correct path to pdf viewer depending on OS
 If TEST is non-nil, it contains a simulation of the OS for test purposes"
-  
+
   (let ((sys-type
          (or test system-type)))
     (cond ((string= sys-type  "darwin")
            ly-OSX-pdf-path)
-          ((string= sys-type "win32")
-           ly-win32-pdf-path)
+          ((string= sys-type "windows-nt")
+           ly-w32-pdf-path)
           (t ly-nix-pdf-path))))
 
 (defun ly-determine-midi-path (&optional test)
   "Return correct path to midi player depending on OS
 If TEST is non-nil, it contains a simulation of the OS for test purposes"
-   
+
   (let ((sys-type
          (or test test system-type)))
     (cond ((string= sys-type  "darwin")
            ly-OSX-midi-path)
-          ((string= sys-type "win32")
-           ly-win32-midi-path)
+          ((string= sys-type "windows-nt")
+           ly-w32-midi-path)
           (t ly-nix-midi-path))))
- 
+
 (defun ly-toggle-midi-play ()
   "Toggle whether midi will be played following a successful compilation"
-  
+
   (interactive)
   (setq ly-play-midi-post-tangle
         (not ly-play-midi-post-tangle))
@@ -374,7 +374,7 @@
 
 (defun ly-toggle-pdf-display ()
   "Toggle whether pdf will be displayed following a successful compilation"
-   
+
   (interactive)
   (setq ly-display-pdf-post-tangle
         (not ly-display-pdf-post-tangle))

=== modified file 'lisp/printing.el'
--- lisp/printing.el    2011-12-15 07:24:10 +0000
+++ lisp/printing.el    2012-01-02 06:41:42 +0000
@@ -2141,7 +2141,7 @@
   `http://bama.ua.edu/cgi-bin/man-cgi?lp'
   `http://www.mediacollege.com/cgi-bin/man/page.cgi?section=all&topic=lp'
 
-* GNU utilities for Win32 (cp.exe)
+* GNU utilities for w32 (cp.exe)
   `http://unxutils.sourceforge.net/'
 "
   :type '(repeat

=== modified file 'nt/ChangeLog'
--- nt/ChangeLog        2011-11-27 18:52:53 +0000
+++ nt/ChangeLog        2012-01-02 06:41:42 +0000
@@ -2065,7 +2065,7 @@
        * makefile.def (CP_DIR): Use platform independent switches for xcopy.
 
        * makefile.nt (install, fast_install, real_install, clean):
-       Don't use switches to del not supported by Win95.
+       Don't use switches to del not supported by Windows 95.
 
 1995-11-07  Kevin Gallo  <address@hidden>
 
@@ -2119,7 +2119,7 @@
 1995-05-27  Geoff Voelker  <address@hidden>
 
        * ebuild.bat, emacs.bat, fast-install.bat, install.bat:
-       Add carriage returns; necessary for batch files on Win95.
+       Add carriage returns; necessary for batch files on Windows 95.
 
 1995-05-25  Geoff Voelker  <address@hidden>
 

=== modified file 'src/ChangeLog'
--- src/ChangeLog       2012-01-01 16:26:51 +0000
+++ src/ChangeLog       2012-01-02 06:41:42 +0000
@@ -1,3 +1,11 @@
+2012-01-02  Paul Eggert  <address@hidden>
+
+       Don't use the abbreviation "win" to refer to Windows.
+       * regex.c (MAX_BUF_SIZE): Remove some incorrect and
+       long-ago-commented-out code that talks about "WIN32".
+       * w32heap.h (OS_WINDOWS_95): Rename from OS_WIN95.
+       All uses changed.
+
 2012-01-01  Eli Zaretskii  <address@hidden>
 
        * gnutls.c (init_gnutls_functions): Load gnutls_check_version.

=== modified file 'src/ChangeLog.10'
--- src/ChangeLog.10    2011-12-12 05:32:49 +0000
+++ src/ChangeLog.10    2012-01-02 06:41:42 +0000
@@ -21476,7 +21476,7 @@
        "Emacs built on Windows 9x/ME crashes at startup on Windows XP,
        or Emacs builtpart of on XP crashes at startup on Windows 9x/ME."
 
-       * w32.c: Added wrapper functions around the win32 API functions
+       * w32.c: Added wrapper functions around the w32 API functions
        OpenProcessToken, GetTokenInformation, LookupAccountSid, and
        GetSidIdentifierAuthority.  These wrapper functions serve two
        purposes:
@@ -21490,7 +21490,7 @@
        the version of advapi32.dll that is found in the 9x branch of
        Microsoft Windows.
 
-       * w32.c (init_user_info): Replace the calls to the win32 API
+       * w32.c (init_user_info): Replace the calls to the w32 API
        functions OpenProcessToken, GetTokenInformation, LookupAccountSid,
        and GetSidIdentifierAuthority with calls to the newly added
        wrapper functions.

=== modified file 'src/ChangeLog.6'
--- src/ChangeLog.6     2011-11-25 13:26:30 +0000
+++ src/ChangeLog.6     2012-01-02 06:41:42 +0000
@@ -1269,7 +1269,7 @@
        "light", "extralight", and "thin" fonts.
        (x_to_win32_charset, win32_to_x_charset): New functions.
        (win32_to_x_font): Use new height units.  Use win32_to_x_charset.
-       (x_to_win32_font): Use x_to_win32_charset.  Support Win32 font names
+       (x_to_win32_font): Use x_to_win32_charset.  Support w32 font names
        in addition to X font names.
 
        (win32_load_font, Fx_list_fonts, Fx_display_color_cells)
@@ -3625,11 +3625,11 @@
 
        * xdisp.c [HAVE_NTGUI] (set_menu_framebar): Declare external.
        [HAVE_NTGUI] (frame_title_buf, frame_title_ptr): Include variables
-       for Win32 window system.
+       for w32 window system.
        [HAVE_NTGUI] (store_frame_title, x_consider_frame_title): Include
-       procedures for Win32 window system.
-       [HAVE_NTGUI] (x_consider_frame_title): Test for Win32 frame.
-       [HAVE_NTGUI] (display_text_line): Test for Win32 frame on face change.
+       procedures for w32 window system.
+       [HAVE_NTGUI] (x_consider_frame_title): Test for w32 frame.
+       [HAVE_NTGUI] (display_text_line): Test for w32 frame on face change.
        [HAVE_NTGUI] (display_menu_bar): Perform no-op for NT window system.
 
        * window.c [HAVE_NTGUI] (Fset_window_configuration): Set menu
@@ -3659,7 +3659,7 @@
        (make_lispy_event): Use FUNCTION_KEY_OFFSET to modify event codes
        before applying modifiers.
 
-       * frame.c [HAVE_NTGUI]: Test for a Win32 frame in procedures
+       * frame.c [HAVE_NTGUI]: Test for a w32 frame in procedures
        that test for an X frame.
 
        * frame.h (output_method): New method: output_win32.
@@ -3673,13 +3673,13 @@
        * emacs.c [HAVE_NTGUI]: Declare Vwindow_system.
        [HAVE_NTGUI] (main): Enable inhibit_window_system.
        Initialize environment from registry.
-       Declare syms of Win32 windowing modules.
+       Declare syms of w32 windowing modules.
 
        * dispnew.c [HAVE_NTGUI]: Include w32term.h.
        Include dispextern.h before cm.h since dispextern.h includes windows.h.
        [HAVE_NTGUI] (make_frame_glyphs, free_frame_glyphs, scroll_frame_lines)
-       (update_frame, update_line): Test for WIN32 frame.
-       [HAVE_NTGUI] (init_display): Initialize WIN32 window system.
+       (update_frame, update_line): Test for w32 frame.
+       [HAVE_NTGUI] (init_display): Initialize w32 window system.
 
        * dispextern.h [HAVE_NTGUI]: Include win32.h.
        [HAVE_NTGUI] (struct frame_glyphs): Include pixel fields.

=== modified file 'src/ChangeLog.7'
--- src/ChangeLog.7     2011-12-14 21:05:20 +0000
+++ src/ChangeLog.7     2012-01-02 06:41:42 +0000
@@ -2070,7 +2070,7 @@
        (sys_select): Ignore children dead children with pending input.
        Delay sending SIGCHLD until all output has been read.
        (sys_kill): Sleep to allow focus change events to propagate.
-       Use TerminateProcess on Win95.
+       Use TerminateProcess on Windows 95.
        (int_from_hex, enum_locale_fn, Fw32_get_valid_locale_ids):
        New functions.
        (Vw32_valid_locale_ids): New variable.
@@ -5720,13 +5720,13 @@
        Loop over handles round robin to ensure fairness.
        (sys_kill): Send ctrl-break and ctrl-c keystrokes to subprocesses
        on SIGINT if not sharing consoles, otherwise generate ctrl-break event.
-       On other termination signals, send WM_QUIT message to Win95 apps
+       On other termination signals, send WM_QUIT message to Windows 95 apps
        and WM_CLOSE to NT apps.
        (syms_of_ntproc): Intern new symbols.  defsubr new functions.
        DEFVAR new variables.
 
-       * w32term.c (SIF_*): Win95 macros defined for NT.
-       (struct tagSCROLLINFO): Win95 struct defined for NT.
+       * w32term.c (SIF_*): Windows 95 macros defined for NT.
+       (struct tagSCROLLINFO): Windows 95 struct defined for NT.
        (vertical_scroll_bar_min_handle, vertical_scroll_bar_top_border)
        (vertical_scroll_bar_bottom_border, last_scroll_bar_drag_pos)
        (Vw32_gab_focus_on_raise, Vw32_capslock_is_shiftlock):

=== modified file 'src/dbusbind.c'
--- src/dbusbind.c      2011-12-17 06:51:13 +0000
+++ src/dbusbind.c      2012-01-02 06:41:42 +0000
@@ -874,7 +874,7 @@
 xd_find_watch_fd (DBusWatch *watch)
 {
 #if HAVE_DBUS_WATCH_GET_UNIX_FD
-  /* TODO: Reverse these on Win32, which prefers the opposite.  */
+  /* TODO: Reverse these on w32, which prefers the opposite.  */
   int fd = dbus_watch_get_unix_fd (watch);
   if (fd == -1)
     fd = dbus_watch_get_socket (watch);

=== modified file 'src/regex.c'
--- src/regex.c 2011-12-05 08:55:25 +0000
+++ src/regex.c 2012-01-02 06:41:42 +0000
@@ -1750,20 +1750,6 @@
    be too small, many things would have to change.  */
 # define MAX_BUF_SIZE (1L << 15)
 
-#if 0  /* This is when we thought it could be 2^16 bytes.  */
-/* Any other compiler which, like MSC, has allocation limit below 2^16
-   bytes will have to use approach similar to what was done below for
-   MSC and drop MAX_BUF_SIZE a bit.  Otherwise you may end up
-   reallocating to 0 bytes.  Such thing is not going to work too well.
-   You have been warned!!  */
-#if defined _MSC_VER  && !defined WIN32
-/* Microsoft C 16-bit versions limit malloc to approx 65512 bytes.  */
-# define MAX_BUF_SIZE  65500L
-#else
-# define MAX_BUF_SIZE (1L << 16)
-#endif
-#endif /* 0 */
-
 /* Extend the buffer by twice its current size via realloc and
    reset the pointers that pointed into the old block to point to the
    correct places in the new one.  If extending the buffer results in it

=== modified file 'src/sound.c'
--- src/sound.c 2011-11-20 07:30:16 +0000
+++ src/sound.c 2012-01-02 06:41:42 +0000
@@ -30,7 +30,7 @@
   cause an error to be generated.
 
   The Windows implementation of play-sound is implemented via the
-  Win32 API functions mciSendString, waveOutGetVolume, and
+  w32 API functions mciSendString, waveOutGetVolume, and
   waveOutSetVolume which are exported by Winmm.dll.
 */
 

=== modified file 'src/w32.c'
--- src/w32.c   2011-12-07 23:14:13 +0000
+++ src/w32.c   2012-01-02 06:41:42 +0000
@@ -2910,7 +2910,7 @@
 
   strcpy (temp, map_w32_filename (oldname, NULL));
 
-  if (os_subtype == OS_WIN95)
+  if (os_subtype == OS_WINDOWS_95)
     {
       char * o;
       char * p;

=== modified file 'src/w32console.c'
--- src/w32console.c    2011-11-20 02:29:42 +0000
+++ src/w32console.c    2012-01-02 06:41:42 +0000
@@ -434,7 +434,7 @@
 {
   CONSOLE_CURSOR_INFO cci;
 
-  /* make cursor big and visible (100 on Win95 makes it disappear)  */
+  /* make cursor big and visible (100 on Windows 95 makes it disappear)  */
   cci.dwSize = 99;
   cci.bVisible = TRUE;
   (void) SetConsoleCursorInfo (cur_screen, &cci);

=== modified file 'src/w32fns.c'
--- src/w32fns.c        2011-12-04 08:02:42 +0000
+++ src/w32fns.c        2012-01-02 06:41:42 +0000
@@ -6598,7 +6598,7 @@
   value = Qnil;
 
   /* Determining the required information on Windows turns out, sadly,
-     to be more involved than one would hope.  The original Win32 api
+     to be more involved than one would hope.  The original w32 api
      call for this will return bogus information on some systems, but we
      must dynamically probe for the replacement api, since that was
      added rather late on.  */

=== modified file 'src/w32heap.c'
--- src/w32heap.c       2011-05-05 04:00:38 +0000
+++ src/w32heap.c       2012-01-02 06:41:42 +0000
@@ -66,7 +66,7 @@
   w32_minor_version = version.info.minor;
 
   if (version.info.platform & 0x8000)
-    os_subtype = OS_WIN95;
+    os_subtype = OS_WINDOWS_95;
   else
     os_subtype = OS_NT;
 
@@ -79,7 +79,7 @@
   GetVersionEx (&osinfo_cache);
 
   w32_build_number = osinfo_cache.dwBuildNumber;
-  if (os_subtype == OS_WIN95)
+  if (os_subtype == OS_WINDOWS_95)
     w32_build_number &= 0xffff;
 }
 
@@ -319,4 +319,3 @@
 }
 
 #endif
-

=== modified file 'src/w32heap.h'
--- src/w32heap.h       2011-01-25 04:08:28 +0000
+++ src/w32heap.h       2012-01-02 06:41:42 +0000
@@ -51,7 +51,7 @@
 extern int           w32_build_number;
 
 enum {
-  OS_WIN95 = 1,
+  OS_WINDOWS_95 = 1,
   OS_NT
 };
 
@@ -92,4 +92,3 @@
 IMAGE_SECTION_HEADER * rva_to_section (DWORD rva, IMAGE_NT_HEADERS * 
nt_header);
 
 #endif /* NTHEAP_H_ */
-

=== modified file 'src/w32proc.c'
--- src/w32proc.c       2011-11-20 02:29:42 +0000
+++ src/w32proc.c       2012-01-02 06:41:42 +0000
@@ -1367,7 +1367,7 @@
 
       GetClassName (hwnd, window_class, sizeof (window_class));
       if (strcmp (window_class,
-                 (os_subtype == OS_WIN95)
+                 (os_subtype == OS_WINDOWS_95)
                  ? "tty"
                  : "ConsoleWindowClass") == 0)
        {
@@ -1498,7 +1498,7 @@
       if (NILP (Vw32_start_process_share_console) && cp && cp->hwnd)
        {
 #if 1
-         if (os_subtype == OS_WIN95)
+         if (os_subtype == OS_WINDOWS_95)
            {
 /*
    Another possibility is to try terminating the VDM out-right by
@@ -1517,7 +1517,7 @@
 
 */
 #if 0
              /* On Win95, posting WM_QUIT causes the 16-bit subsystem
                 to hang when cmdproxy is used in conjunction with
                 command.com for an interactive shell.  Posting
                 WM_CLOSE pops up a dialog that, when Yes is selected,
@@ -1791,7 +1791,7 @@
       CHECK_NUMBER (process);
 
       /* Allow pid to be an internally generated one, or one obtained
-        externally.  This is necessary because real pids on Win95 are
+        externally.  This is necessary because real pids on Windows 95 are
         negative.  */
 
       pid = XINT (process);




--- End Message ---
--- Begin Message --- Subject: Re: bug#10421: Don't use the abbreviation "win" to refer to Windows. Date: Sun, 29 Jul 2012 01:20:48 -0700 User-agent: Mozilla/5.0 (X11; Linux i686; rv:14.0) Gecko/20120714 Thunderbird/14.0
I merged this change into the current trunk as
bzr 109257 and am marking it as done.


--- End Message ---
@@ -1517,7 +1517,7 @@
 */
 #if 0
-             /* On Win95, posting WM_QUIT causes the 16-bit subsystem
+             /* On Windows 95, posting WM_QUIT causes the 16-bit subsystem
                 to hang when cmdproxy is used in conjunction with
                 command.com for an interactive shell.  Posting

reply via email to

[Prev in Thread] Current Thread [Next in Thread]